### Name: ssa
### Title: Invoking the stochastic simulation algorithm
### Aliases: ssa
### Keywords: misc datagen ts

### ** Examples

## Irreversible isomerization
parms <- c(c=0.5)
x0  <- c(X=10000)
a   <- c("c*X")
nu  <- matrix(-1)
out <- ssa(x0,a,nu,parms,tf=10,simName="Irreversible isomerization") # Direct method
## Not run: 
##D plot(out$data[,1],out$data[,2]/10000,col="red",cex=0.5,pch=19)
## End(Not run)

x0  <- c(X=100)
out <- ssa(x0,a,nu,parms,tf=10) # Direct method
## Not run: 
##D points(out$data[,1],out$data[,2]/100,col="green",cex=0.5,pch=19)
## End(Not run)

x0  <- c(X=10)
out <- ssa(x0,a,nu,parms,tf=10) # Direct method
## Not run: 
##D points(out$data[,1],out$data[,2]/10,col="blue",cex=0.5,pch=19)
## End(Not run)

## Logistic growth
parms <- c(b=2, d=1, K=1000)
x0  <- c(N=500)
a   <- c("b*N", "(d+(b-d)*N/K)*N")
nu  <- matrix(c(+1,-1),ncol=2)
out <- ssa(x0,a,nu,parms,tf=10,method="D",maxWallTime=5,simName="Logistic growth")
## Not run: 
##D ssa.plot(out)
## End(Not run)

## Kermack-McKendrick SIR model 
parms <- c(beta=0.001, gamma=0.1)
x0  <- c(S=499,I=1,R=0)
a   <- c("beta*S*I","gamma*I") 
nu  <- matrix(c(-1,0,+1,-1,0,+1),nrow=3,byrow=TRUE)
out <- ssa(x0,a,nu,parms,tf=100,simName="SIR model")
## Not run: 
##D ssa.plot(out)
## End(Not run)

## Lotka predator-prey model
parms <- c(c1=10, c2=.01, c3=10)
x0  <- c(Y1=1000,Y2=1000)
a   <- c("c1*Y1","c2*Y1*Y2","c3*Y2")
nu  <- matrix(c(+1,-1,0,0,+1,-1),nrow=2,byrow=TRUE) 
out <- ssa(x0,a,nu,parms,tf=100,method="ETL",simName="Lotka predator-prey model")
## Not run: 
##D ssa.plot(out)
## End(Not run)



